@@ -19,14 +19,23 @@ else:
 class Run:
     def __init__(self, command, path, image, tag):
         self.path=path
-        #self.command = "bash -c '" + command + "'"
-        self.command = command
+        #look for bash pipes, if they exist use bash to run command otherwise run via docker
+        if ">" in command or "<" in command or "|" in command or ";" in command or "&" in command:
+            self.command = "bash -c '" + command + "'"
+        else:
+            self.command = command
         self.image = image
         self.tag = tag
 
     def run(self):
+        #check if we got a local singularity image
+        if os.path.isfile(self.image):
+            container = self.image
+        else:
+            container = f"{self.image}:{self.tag}"
+
         try:
-            for line in container_engine.call(f"{self.image}:{self.tag}", self.command, '/data', self.path):
+            for line in container_engine.call(container, self.command, '/data', self.path):
                 print(line)
         except KeyboardInterrupt:
             container_engine.shutdown()
